@@ -25,19 +25,27 @@ Validate values obtained from the ``YAML`` file and coerce into the appropriate
 #  OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
 #  OR OTHER DEALINGS IN THE SOFTWARE.
 #
+#  validate based on https://github.com/yaccob/ytools
+#  Copyright (c) Jakob Stemberger <yaccob@gmx.net>
+#  Apache 2.0 Licensed
+#
 
 # stdlib
+import pathlib
 from typing import Any, Dict, Iterable, List, NoReturn, Optional, Union
 
 # 3rd party
+import jsonschema  # type: ignore
+from domdf_python_tools.typing import PathLike
 from domdf_python_tools.utils import strtobool
+from ruamel.yaml import safe_load, safe_load_all
 from typing_inspect import get_origin, is_literal_type  # type: ignore
 
 # this package
 from configconfig.metaclass import ConfigVarMeta
 from configconfig.utils import check_union, get_literal_values, optional_getter
 
-__all__ = ["Validator"]
+__all__ = ["Validator", "validate_files"]
 
 RawConfigVars = Dict[str, Any]
 
@@ -93,7 +101,7 @@ class Validator:
 	def _visit_str_number(self, raw_config_vars: RawConfigVars) -> Union[str, int, float]:
 		obj = optional_getter(raw_config_vars, self.config_var, self.config_var.required)
 
-		if not isinstance(obj, self.config_var.dtype):  # type: ignore
+		if not isinstance(obj, self.config_var.dtype):
 			raise ValueError(f"'{self.config_var.__name__}' must be a {self.config_var.dtype}") from None
 
 		return obj
@@ -134,7 +142,7 @@ class Validator:
 
 		obj = optional_getter(raw_config_vars, self.config_var, self.config_var.required)
 
-		if not isinstance(obj, (int, bool, str)):  # type: ignore
+		if not isinstance(obj, (int, bool, str)):
 			raise ValueError(f"'{self.config_var.__name__}' must be one of {(int, bool, str)}") from None
 
 		return self.config_var.rtype(strtobool(obj))
@@ -157,7 +165,7 @@ class Validator:
 
 		if get_origin(self.config_var.dtype.__args__[0]) is Union:
 			for obj in data:
-				if not check_union(obj, self.config_var.dtype.__args__[0]):  # type: ignore
+				if not check_union(obj, self.config_var.dtype.__args__[0]):
 					raise ValueError(
 							f"'{self.config_var.__name__}' must be a List of {self.config_var.dtype.__args__[0]}"
 							) from None
@@ -172,7 +180,7 @@ class Validator:
 							) from None
 		else:
 			for obj in data:
-				if not check_union(obj, self.config_var.dtype):  # type: ignore
+				if not check_union(obj, self.config_var.dtype):
 					raise ValueError(
 							f"'{self.config_var.__name__}' must be a List of {self.config_var.dtype.__args__[0]}"
 							) from None
@@ -180,9 +188,9 @@ class Validator:
 		try:
 			for obj in data:
 				if self.config_var.rtype.__args__[0] in {int, str, float, bool}:
-					buf.append(self.config_var.rtype.__args__[0](obj))  # type: ignore
+					buf.append(self.config_var.rtype.__args__[0](obj))
 				else:
-					buf.append(obj)  # type: ignore
+					buf.append(obj)
 
 			return buf
 
@@ -269,3 +277,31 @@ class Validator:
 		print(self.config_var.dtype)
 		print(get_origin(self.config_var.dtype))
 		raise NotImplementedError
+
+
+def validate_files(
+		schemafile: PathLike,
+		*datafiles: PathLike,
+		encoding: str = "utf-8",
+		) -> None:
+	r"""
+	Validate the given datafiles against the given schema.
+
+	:param schemafile: The ``json`` or ``yaml`` formatted schema to validate with
+	:param \*datafiles: The ``json`` or ``yaml`` files to validate
+	:param encoding: Encoding to open the files with.
+
+	.. versionadded:: 0.4.0
+	"""
+
+	schemafile = pathlib.Path(schemafile)
+
+	schema = safe_load(schemafile.read_text(encoding=encoding))
+
+	for filename in datafiles:
+		for document in safe_load_all(pathlib.Path(filename).read_text(encoding=encoding)):
+			try:
+				jsonschema.validate(document, schema, format_checker=jsonschema.FormatChecker())
+			except jsonschema.exceptions.ValidationError as e:
+				e.filename = str(filename)
+				raise e
